@@ -65,17 +65,18 @@ open_file_destroy_cb (GtkWidget *w,
 
 
 static gboolean
-only_spaces (const char *text)
+utf8_only_spaces (const char *text)
 {
-	int l, i;
+	const char *scan;
 	
 	if (text == NULL)
 		return TRUE;
 
-	l = strlen (text);
-	for (i = 0; i < l; i++)
-		if (*text != ' ')
+	for (scan = text; *scan != 0; scan = g_utf8_next_char (scan)) {
+		gunichar c = g_utf8_get_char (scan);
+		if (! g_unichar_isspace (c))
 			return FALSE;
+	}
 
 	return TRUE;
 }
@@ -109,14 +110,20 @@ open_file_ok_cb (GtkWidget *w,
 	    && access (base_dir, R_OK | X_OK) != 0) {
 		GtkWidget *d;
 		char      *utf8_path;
+		char      *message;
 
 		utf8_path = g_locale_to_utf8 (base_dir, -1, NULL, NULL, NULL);
-		d = gtk_message_dialog_new (GTK_WINDOW (window->app),
-					    GTK_DIALOG_DESTROY_WITH_PARENT,
-					    GTK_MESSAGE_ERROR,
-					    GTK_BUTTONS_CLOSE,
-					    _("You don't have the right permissions to read files from folder \"%s\""),
-					    utf8_path);
+		message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
+		g_free (utf8_path);
+
+		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+					     GTK_DIALOG_MODAL,
+					     GTK_STOCK_DIALOG_ERROR,
+					     _("Could not add the files to the archive"),
+					     _("You don't have the right permissions to read files from folder \"%s\""),
+					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					     GTK_STOCK_OK, GTK_RESPONSE_OK,
+					     NULL);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
 		g_free (utf8_path);
@@ -186,6 +193,7 @@ open_file_ok_cb (GtkWidget *w,
 		gboolean    no_backup_files;
 		gboolean    no_dot_files;
 		gboolean    ignore_case;
+		char       *include_files;
 		const char *exclude_files;
 
 		recursive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton));
@@ -197,13 +205,15 @@ open_file_ok_cb (GtkWidget *w,
 
 		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton))) {
 			exclude_files = gtk_entry_get_text (GTK_ENTRY (data->exclude_files_entry));
-			if (only_spaces (exclude_files))
+			if (utf8_only_spaces (exclude_files)) 
 				exclude_files = NULL;
 		} else
 			exclude_files = NULL;
 
+		include_files = g_locale_to_utf8 (file_name_from_path (path), 
+						  -1, 0, 0, 0);
 		window_archive_add_with_wildcard (window,
-						  file_name_from_path (path),
+						  include_files,
 						  exclude_files,
 						  base_dir,
 						  update,
@@ -215,6 +225,7 @@ open_file_ok_cb (GtkWidget *w,
 						  ignore_case,
 						  window->password,
 						  window->compression);
+		g_free (include_files);
 	}
 
 	g_free (path);
@@ -341,7 +352,7 @@ add_cb (GtkWidget *widget,
  
 	data = g_new (DialogData, 1);
 	data->window = callback_data;
-	data->dialog = file_sel = gtk_file_selection_new (_("Add Files and Folders"));
+	data->dialog = file_sel = gtk_file_selection_new (_("Add Files"));
 	gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (file_sel));
 
 	gtk_file_selection_set_select_multiple (GTK_FILE_SELECTION (file_sel), TRUE);
@@ -584,7 +595,7 @@ load_options_ok_cb (GtkWidget *w,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_backup_files), no_backup_files);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_dot_files), no_dot_files);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->ignore_case), ignore_case);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton), ! only_spaces (exclude_files));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton), ! utf8_only_spaces (exclude_files));
 	gtk_entry_set_text (GTK_ENTRY (data->exclude_files_entry), exclude_files);
 	
 	/**/
@@ -718,7 +729,7 @@ save_options_ok_cb (GtkWidget *w,
 	
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton))) {
 		exclude_files = gtk_entry_get_text (GTK_ENTRY (data->exclude_files_entry));
-		if (only_spaces (exclude_files))
+		if (utf8_only_spaces (exclude_files))
 			exclude_files = NULL;
 	} else
 		exclude_files = NULL;
